@@ -12,8 +12,8 @@ missing climate data using minimal data.
 import math
 import datetime as dt
 
-CHECK_RADIATION_RANGE=True
-CHECK_SUNSHINE_HOURS_RANGE=True
+CHECK_RADIATION_RANGE = True
+CHECK_SUNSHINE_HOURS_RANGE = True
 
 def is_number(s):
     try:
@@ -22,33 +22,38 @@ def is_number(s):
     except ValueError:
         return False
 
-
 class Station:
     """ Class that implements a weather station at a known latitude and elevation."""
 
     def __init__(self, latitude, altitude, anemometer_height=2):
         """
         Required parameters:
-        
+
         :param latitude: latitude of the location in decimal format. For southern
             hemisphere negative number must be used
         :type latitude: float
-        
+
         :param altitude: altitude (elevation) of the location in meters
         :type altitude: int
-        
+
         :param anemometer_height=2: height of the anemometer (wind-speed)
             measuring device
         :type anemometer_height: int
-        
+
         Following are additional attributes that you can get/set on this station
         after instantiation:
-        
+
          * latitude_rad - latitude in radian, alculated based on latitude
          * days - dictionary of days recorded (or calculated) by this station
          * climate - set to default **Climate()** instance
          * ref_crop - instance of **Crop** class, which sets default chracteristics
                       of the reference crop according to the paper.
+                      
+        Should you wish to change assumes Climate and Crop characteristics
+        you can do so after the object is innitialized, like so:
+        
+            station=Station(41.42, 109)
+            station.ref_crop = Crop(albedo=0.25, height=0.35)
         """
 
         if not type(latitude) is float:
@@ -77,12 +82,13 @@ class Station:
         """ See get_day()"""
         return self.get_day(day_number)
 
-    def get_day(self, day_number, date_template="%Y-%m-%d", 
-                temp_min=None, 
-                temp_max=None, 
-                wind_speed=None, 
-                humidity_mean=None, 
-                radiation_s=None, 
+    def get_day(self, day_number, date_template="%Y-%m-%d",
+                temp_min=None,
+                temp_max=None,
+                temp_mean=None,
+                wind_speed=None,
+                humidity_mean=None,
+                radiation_s=None,
                 sunshine_hours=None
                 ):
         """
@@ -98,15 +104,15 @@ class Station:
             day = station.get_day(229)
             day = station.get_day("2020-08-16")
             day = station.get_day('08/16/2020', '%m/%d/%Y')
-            
+
         You can pass the following named-parameters to the method:
-        
+
          - temp_min
          - temp_max
          - wind_speed
          - radiation_s
          - sunshine_hours
-         
+
          If *radiation_s* and *sunshine_hours* is out of range for this location
          for this date (based on solar declination, sun-distance and daylight hours)
          raises ValueError exception.
@@ -134,9 +140,10 @@ class Station:
         self.days[day_number] = day
         day.temp_min = temp_min
         day.temp_max = temp_max
+        day.temp_mean=temp_mean
         day.humidity_mean = humidity_mean
         day.wind_speed = wind_speed
-        
+
         if radiation_s:
             if CHECK_RADIATION_RANGE:
                 if radiation_s <= day.R_so():
@@ -148,12 +155,12 @@ class Station:
 
         if sunshine_hours:
             if CHECK_SUNSHINE_HOURS_RANGE:
-                if  sunshine_hours <= day.daylight_hours() :
+                if sunshine_hours <= day.daylight_hours():
                     day.sunshine_hours = sunshine_hours
                 else:
                     raise ValueError("Sunshine hours out of range")
             else:
-                day.sunshine_hours=sunshine_hours
+                day.sunshine_hours = sunshine_hours
 
         return day
 
@@ -205,7 +212,6 @@ class StationDay:
         - vapour_pressure
         - wind_speed
         - radiation_s
-        - radiation_a
         - stephan_boltzman_constant
         - climate  - convenient reference to station.climate
         - sunshine_hours
@@ -223,7 +229,6 @@ class StationDay:
         self.humidity_max = None
         self.wind_speed = None
         self.radiation_s = None
-        self.radiation_a = None
         self.temp_dew = None
         self.temp_dry = None
         self.temp_wet = None
@@ -252,9 +257,8 @@ class StationDay:
         # if wind speed at height different than 2m is given, calculate wind
         # speed at 2m
         if self.wind_speed and self.station.anemometer_height != 2:
-            self.wind_speed = round(self.wind_speed * (4.87 /
-                                                       math.log(67.8 * self.station.anemometer_height - 5.42)), 1)
-            return self.wind_speed
+            return round(self.wind_speed * (4.87 /
+                                            math.log(67.8 * self.station.anemometer_height - 5.42)), 1)
 
         # if we reach this far no wind information is available to work with. we
         # consult if station has any climatic data, in which case we try to
@@ -469,10 +473,11 @@ class StationDay:
         if self.radiation_s:
             # We need to make sure that solar radiation if set, is not
             # larger than clear-sky solar radiation
-            if CHECK_RADIATION_RANGE and ( self.radiation_s > self.R_so() ):
-                raise ValueError("Solar radiation out ot range. Rso="+str(self.R_so()))
+            if CHECK_RADIATION_RANGE and (self.radiation_s > self.R_so()):
+                raise ValueError(
+                    "Solar radiation out ot range. Rso=" + str(self.R_so()))
             return self.radiation_s
-        
+
         n = self.sunshine_hours
         if n == None:
             # if we are in island location we refer to equation 51 in UAN-FAO
@@ -506,8 +511,8 @@ class StationDay:
             raise ValueError("Observed daylight hours cannot be less than 0")
 
         # n cannot be more than N, which is available daylight hours
-        if ( n > self.daylight_hours() ) and CHECK_SUNSHINE_HOURS_RANGE:
-            raise ValueError( "Daylight hours out of range" )
+        if (n > self.daylight_hours()) and CHECK_SUNSHINE_HOURS_RANGE:
+            raise ValueError("Daylight hours out of range")
 
         a_s = 0.25
         b_s = 0.50
@@ -538,7 +543,7 @@ class StationDay:
 
     def R_ns(self):
         """
-        Net solar or net shortwave radiation. Uses Cro's albedo in calculations. (Eq. 38). 
+        Net solar or net shortwave radiation. Uses Crop's albedo in calculations. (Eq. 38). 
         Return radiation in MJ/m2/day
 
         """
@@ -550,6 +555,9 @@ class StationDay:
         """
         Net longwave radiation. (Eq. 39)
         """
+        
+        if not ( self.temp_max and self.temp_min ):
+            raise Exception("Net longwave radiation cannot be calculated without min/max temperature")
 
         TmaxK = self.temp_max + 273.16
         TminK = self.temp_min + 273.16
@@ -559,14 +567,19 @@ class StationDay:
 
         sb_constant = self.stephan_boltzmann_constant
         return round(sb_constant * ((TmaxK ** 4 + TminK ** 4) / 2) *
-                     (0.34 - 0.14 * math.sqrt(ea)) * (1.35 * (rs / rso) - 0.35), 1)
+                     (0.34 - 0.14 * math.sqrt(ea)) *
+                     (1.35 * (rs / rso) - 0.35), 1)
 
     def net_radiation(self):
         """
         Net Radiation. (Eq. 40)
         """
         ns = self.R_ns()
-        nl = self.R_nl()
+        
+        try: 
+            nl = self.R_nl()
+        except Exception as e: 
+            raise(str(e))
 
         if (not ns is None) and (not nl is None):
             return round(ns - nl, 1)
@@ -611,31 +624,32 @@ class StationDay:
         Eq. 6
         """
 
-        Tmax = self.temp_max
-        Tmin = self.temp_min
-
         # if we cannot get wind speed data we revert to Hargreaves formula.
-        # Which is not ideal!
+        # Which is not ideal! This can happen only if user removed default 'climate'
+        # reference
         if not self.wind_speed_2m():
             return self.eto_hargreaves()
 
-        if Tmax and Tmin:
-            Tmean = (Tmax + Tmin) / 2
 
-            slope_of_vp = self.slope_of_saturation_vapour_pressure(Tmean)
+        if self.Tmean() == None:
+            raise Exception(
+                "Cannot calculate eto(): temp_mean (mean temperature) is missing")
+
+        try:
             net_radiation = self.net_radiation()
-            G = self.soil_heat_flux()
-            u2m = self.wind_speed_2m()
+        except Exception as e:
+            raise(str(e))
 
-            eto_nominator = (0.408 * slope_of_vp * (net_radiation - G) +
-                             self.psychrometric_constant() * (900 / (Tmean + 273)) * u2m *
-                             self.vapour_pressure_deficit())
+        Tmean=self.Tmean()
+        slope_of_vp = self.slope_of_saturation_vapour_pressure(Tmean)
+        G = self.soil_heat_flux()
+        u2m = self.wind_speed_2m()
+        eto_nominator = (0.408 * slope_of_vp * (net_radiation - G) +
+                         self.psychrometric_constant() * (900 / (Tmean + 273)) * u2m *
+                         self.vapour_pressure_deficit())
 
-            eto_denominator = slope_of_vp + self.psychrometric_constant() * (1 + 0.34 * u2m)
-
-            return round(eto_nominator / eto_denominator, 2)
-
-        return None
+        eto_denominator = slope_of_vp + self.psychrometric_constant() * (1 + 0.34 * u2m)
+        return round(eto_nominator / eto_denominator, 2)
 
 
 class Climate:
@@ -750,6 +764,7 @@ class Climate:
         self.k_rs = 0.19
         return self
 
+    """
     def set_location(self, location):
         if location == "coastal":
             return self.coastal()
@@ -761,6 +776,7 @@ class Climate:
             return self.island()
 
         return self
+    """
 
     def describe(self):
         location = ""
@@ -783,7 +799,7 @@ day's minimal observed temperature"""
 
 
 class Crop:
-    """ Represents reference crop as assumed by Penman-Monteith equation.""" 
+    """ Represents reference crop as assumed by Penman-Monteith equation."""
 
     def __init__(self, resistance_a=208, albedo=0.23, height=0.12):
         """
